Войти или зарегистрироваться

# Письмо администрации Лайвлиба

Ваше имя:
Ваш email:
Категория вопроса:
Реклама, партнерство, сотрудничество
Раздачи книг
Вакансии на ЛЛ
Пожелания, предложения
Разместить информацию об авторах, книгах
Ошибки на сайте
Вопросы по работе сайта
Электронные книги
Продажа и публикация книг
Другие вопросы
Обратите внимание! Вы можете опубликовать платное текстовое объявление на Лайвлибе: http://www.livelib.ru/service.
Пожалуйста, отправьте нам сообщение по другим вопросам рекламы и сотрудничества.
Лайвлиб не занимается продажей и публикацией книг. На нашем сайте пользователи отмечают и обсуждают прочитанные книги. На страницах книг указаны ссылки на магазины наших партнеров, если книги есть в наличии.
Вопросы по работе сайта быстрее всего решаются в открытой теме техподдержки.
Обратите внимание! Ответы на часто задаваемые вопросы находятся на странице http://www.livelib.ru/faq.
На следующий после регистрации день вы сможете добавить на сайт информацию о новой книге. Форма добавления находится на странице http://www.livelib.ru/addons/addbook.
Чтобы отредактировать информацию об авторе или книге, станьте куратором автора или книги. Для этого на странице нужной книги или автора нажмите ссылку Хочу курировать.
Обратите внимание! Эта возможность также появляется на следующий после регистрации день.
Издательства или авторы могут в рекламных целях организовать раздачу своих книг среди читателей Лайвлиба.
Пожалуйста, напишите:
- сколько экземпляров книг вы хотите раздать,
- какой будет срок проведения раздачи (рекомендуем 2-4 недели),
- читатели из каких регионов могут участвовать (рекомендуем РФ или СНГ).
Обратите внимание! Организация раздачи бесплатна, но пересылку книг победителям полностью оплачиваете вы.
Список открытых вакансий Лайвлиба публикуется на странице http://www.livelib.ru/join.
Загляните в Центр управления полетами, в нем собрано много предложений с обсуждениями.
На Лайвлибе нет возможности скачивать электронные книги. На нашем сайте пользователи отмечают и обсуждают прочитанные книги. Вы можете приобрести электронные книги, например, на Литресе.
Сообщение:

контактная информация

Идет загрузка...